@@ -23,10 +23,15 @@ from naas_drivers.inputOutput.git import Git
 from naas_drivers.inputOutput.gsheet import Gsheet
 from naas_drivers.inputOutput.mongo import Mongo
 from naas_drivers.inputOutput.toucan import Toucan
+from naas_drivers.inputOutput.linkedin import Linkedin
+from naas_drivers.inputOutput.notion import Notion
+from naas_drivers.inputOutput.hubspot import Hubspot
+from naas_drivers.inputOutput.thinkific import Thinkific
+
 import requests
 import os
 
-__version__ = "0.37.0"
+__version__ = "0.38.1"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -61,8 +66,12 @@ jupyter = Jupyter()
 ftp = Ftp()
 git = Git()
 gsheet = Gsheet()
+notion = Notion()
 mongo = Mongo()
 toucan = Toucan()
+linkedin = Linkedin()
+hubspot = Hubspot()
+thinkific = Thinkific()
 
 __doc_url = "https://naas.gitbook.io/drivers/"
 
