@@ -228,12 +228,17 @@ class Html(InDriver):
         row_link_index = -1
         if isinstance(data, pd.DataFrame):
             table_arr = list(data.values.tolist())
-            row_link = "row_link" in data.columns
-            row_link_index = list(data.columns).index("row_link")
+            row_link = True if "row_link" in data.columns else False
+            try:
+                row_link_index = list(data.columns).index("row_link")
+            except ValueError:
+                pass
         elif isinstance(data, list):
             table_arr = data
         else:
-            raise ValueError("Table should be array")
+            error_text = f"Table should be array, not {data.__name__}"
+            self.print_error(error_text)
+            return None
         for row in table_arr:
             res = []
             if isinstance(row, list):
@@ -421,7 +426,8 @@ class Html(InDriver):
             output = "pdf"
             json["pdf"] = {"width": "20.5cm", "height": "36.5cm"}
         else:
-            raise ValueError("extension now suported for now")
+            error_text = f"extension {filename.split('.')[1]} not suported for now"
+            self.print_error(error_text)
         json["output"] = output
         req = requests.post(
             url=f"{os.environ.get('SCREENSHOT_API', 'http://naas-screenshot:9000')}/api/render",
@@ -445,7 +451,8 @@ class Html(InDriver):
         if input_type == "markdown":
             return markdown2.markdown(data_read)
         else:
-            raise ValueError(f"{input_type} not supported for now")
+            error_text = f"{input_type} not supported for now"
+            self.print_error(error_text)
 
     def export(self, html, filenames, css=None):
         """ create html export and add css to it"""
